<?php

namespace App\Http\Middleware;

use Closure;
use Illuminate\Contracts\Auth\Factory as Auth;

class Authenticate
{
    /**
     * The authentication guard factory instance.
     *
     * @var \Illuminate\Contracts\Auth\Factory
     */
    protected $auth;

    /**
     * Create a new middleware instance.
     *
     * @param  \Illuminate\Contracts\Auth\Factory $auth
     * @return void
     */
    public function __construct(Auth $auth)
    {
        $this->auth = $auth;
    }

    /**
     * Handle an incoming request.
     *
     * @param  \Illuminate\Http\Request $request
     * @param  \Closure $next
     * @param  string|null $guard
     * @return mixed
     */
    public function handle($request, Closure $next, $guard = null)
    {
        if ($this->auth->guard($guard)->guest()) {
            $error = [
                'message' => '请重新登录',
                'code' => 401,
            ];
            return response()->json($error)->setStatusCode(401);
        }
        $user = $this->auth->user();
        if (!verifySign($request->get('sign'), $request->all(), config('customer.app_secret'))) {
            $error = [
                'message' => '数据验签失败',
                'code' => 401,
            ];
            return response()->json($error)->setStatusCode(401);
        }
        return $next($request);
    }
}
